﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Globalization;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.Windows;

namespace XdgIdei
{
    public class MyClass : INotifyPropertyChanged
    {

        private decimal price;

        public decimal Price
        {
            get { return price; }
            set { price = value; ValidatePriceProperty(value, "Price"); }
        }
        private decimal price2;

        public decimal Price2
        {
            get { return price2; }
            set { price2 = value; ValidatePriceProperty(value, "Price2"); }
        }
        private decimal price3;

        public decimal Price3
        {
            get { return price3; }
            set { price3 = value; ValidatePriceProperty(value, "Price3"); }
        }

        private Dictionary<string, string> errors;

        private void ValidatePriceProperty(decimal value, string propertyName)
        {
            var priceValidationRule = new PriceValidationRule();

            var result = priceValidationRule.Validate(value, CultureInfo.CurrentCulture);

            if (!result.IsValid)
            {
                if (errors.ContainsKey(propertyName))
                    errors[propertyName] = result.ErrorContent.ToString();
                else
                    errors.Add(propertyName, result.ErrorContent.ToString());
            }
            else
            {
                if (errors.ContainsKey(propertyName))
                    errors.Remove(propertyName);
            }

            NotifyPropertyChanged(propertyName);
            NotifyPropertyChanged("HasError");
        }

        public bool HasError { get { return errors.Count > 0; } }

        public MyClass()
        {
            errors = new Dictionary<string, string>();
        }

        #region PropertyChanged Implementation

        public event PropertyChangedEventHandler PropertyChanged;

        private void NotifyPropertyChanged(string info)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(info));
            }
        }

        #endregion // PropertyChanged Implementation

    }
}
